# CalculyFy V-1.0

CalculyFy is a simple and cool python library to help you understand how to create python packages.

It is also capable of some cool math calculations.

CalculyFy is written in [Python](https://www.python.org/).


# Installation

You can install CalculyFy by running:

```
$ pip install CalculyFy
```


# Usage

## Get Started

To get started with CalculyFy simply do the following steps:

1. Create a python file(*.py) and inside that file type:

```
import calculyfy
```
And Use It's Finctioanlities.

# Dependencies

## Packages:
 
- [Colorama](https://pypi.org/project/colorama/)

# About The Author

Hello Everyone!

I'm Artin, a freelance programmer.
CalculyFy Library is just a test library to only show you how to create python packages which has a video in my YouTube channel and here is the link to the video: [VIDEO_LINK_HERE], I hope you like it.

Thank you all.